package main

import (
	"errors"
	"flag"
	"fmt"
	"os"
	"path/filepath"
	"strconv"
	"strings"
	"time"

	"github.com/fatih/color"
)

const VERSION = "1.0.0"

var unsupportedDirectories = []string{"/proc", "/dev", "/sys"}

func countSystemAge(path string) error {
	// Check if the path is in the unsupported directories
	for _, dir := range unsupportedDirectories {
		if path == dir {
			return errors.New(color.RedString("ERROR") + "Directories such as /proc, /dev, /sys are not supported.")
		}
	}
	// Check if the path exists
	info, err := os.Stat(path)
	if os.IsNotExist(err) {
		return fmt.Errorf("ERROR: No such file or directory: %s", path)
	} else if err != nil {
		return err
	}

	createdTime := info.ModTime()

	now := time.Now()
	duration := now.Sub(createdTime)

	totalDays := int(duration.Hours() / 24)
	years := totalDays / 365
	months := (totalDays % 365) / 30
	days := (totalDays % 365) % 30

	yearLabel := "Year"
	if years != 1 {
		yearLabel = "Years"
	}

	monthLabel := "Month"
	if months != 1 {
		monthLabel = "Months"
	}

	dayLabel := "Day"
	if days != 1 {
		dayLabel = "Days"
	}

	year_string := strconv.Itoa(years)
	months_string := strconv.Itoa(months)
	days_string := strconv.Itoa(days)

	fmt.Printf("%s %s %s %s %s %s\n", color.YellowString(year_string), color.YellowString(yearLabel), color.GreenString(months_string), color.GreenString(monthLabel), color.BlueString(days_string), color.BlueString(dayLabel))
	return nil
}

func main() {
	pathFlag := flag.String("path", "/", "Path to calculate the age of the system")
	versionFlag := flag.Bool("version", false, "Show version")
	flag.Parse()

	if *versionFlag {
		fmt.Printf("Hourglass: %s\n", VERSION)
		os.Exit(0)
	}

	path := strings.TrimSpace(*pathFlag)
	if err := countSystemAge(filepath.Clean(path)); err != nil {
		fmt.Println(err)
		os.Exit(1)
	}
}
